using Hotline.Share.Dtos.Snapshot;
using Hotline.Snapshot;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Application.Snapshot.Contracts;
public interface IIndustryApplication
{
    /// <summary>
    /// 新增行业
    /// </summary>
    /// <returns></returns>
    Task<string> AddIndustryAsync(AddIndustryDto dto, CancellationToken cancellationToken);

    /// <summary>
    /// 获取行业集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<IndustryItemsOutDto> GetIndustres(IndustryListInDto dto);

    /// <summary>
    /// 获取行业详情
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task<IndustryDetailOutDto> GetIndustryDetailAsync(string id, CancellationToken token);

    /// <summary>
    /// 修改行业
    /// </summary>
    /// <param name="dto"></param>
    /// <param name="requestAborted"></param>
    /// <returns></returns>
    Task UpdateIndustryAsync(UpdateIndustryInDto dto, CancellationToken requestAborted);

    /// <summary>
    /// 行业线索集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<IndustryCaseItemOutDto> GetIndustryCaseItems(IndustryCaseItemInDto dto);

    /// <summary>
    /// 添加行业线索
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<string> AddIndustryCaseAsync(AddIndustryCaseDto dto);

    /// <summary>
    /// 修改行业线索
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task UpdateIndustryCaseAsync(UpdateIndustryCaseDto dto);

    /// <summary>
    /// 获取行业线索详情
    /// </summary>
    /// <param name="caseId"></param>
    /// <returns></returns>
    Task<IndustryCase> GetIndustryCaseAsync(string caseId);

    /// <summary>
    /// 添加行业模板
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<string> AddSMSTemplateAsync(AddSnapshotSMSTemplateInDto dto);

    /// <summary>
    /// 行业模板集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<SnapshotSMSTemplateItemsOutDto> GetSMSTemplates(SnapshotSMSTemplateItemsInDto dto);

    /// <summary>
    /// 修改行业模板
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task UpdateSMSTemplateAsync(UpdateSnapshotSMSTemplateInDto dto);

    /// <summary>
    /// 短信详情
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task<SnapshotSMSTemplateItemsOutDto> GetSMSTemplateDetailAsync(string id);

    /// <summary>
    /// 区域从业人员集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<PractitionerItemsOutDto> GetPractitionerItems(PractitionerItemsInDto dto);

    /// <summary>
    /// 删除区域从业人员
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task DeletePractitionerAsync(IList<string> id);

    /// <summary>
    /// 修改区域从业人员
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task UpdatePractitionerAsync(UpdatePractitionerInDto dto);

    /// <summary>
    /// 添加区域从业人员
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<string> AddPractitionerAsync(AddPractitionerInDto dto);

    /// <summary>
    /// 区域从业人员详情
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task<PractitionerItemsOutDto> GetPractitionerAsync(string id);

    /// <summary>
    /// 志愿者集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<VolunteerItemsOutDto> GetVolunteerItems(VolunteerItemsInDto dto);

    /// <summary>
    /// 添加志愿者
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<string> AddVolunteerAsync(AddVolunteerInDto dto);

    /// <summary>
    /// 批量删除志愿者
    /// </summary>
    /// <param name="ids"></param>
    /// <returns></returns>
    Task DeleteVolunteerAsync(IList<string> ids);

    /// <summary>
    /// 志愿者详情
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task<Volunteer> GetVolunteerAsync(string id);

    /// <summary>
    /// 修改志愿者
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task UpdateVolunteerAsync(UpdateVolunteerInDto dto);

    /// <summary>
    /// 志愿者上报集合
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<VolunteerReportItemsOutDto> GetVolunteerReportItems(VolunteerReportItemsInDto dto);

    /// <summary>
    /// 行业修改记录
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    ISugarQueryable<IndustryLogItemsOutDto> GetIndustryLogItems(IndustryLogItemsInDto dto);

    /// <summary>
    /// 删除行业短信模板
    /// </summary>
    /// <param name="ids"></param>
    /// <returns></returns>
    Task DeleteSMSTemplateAsync(IList<string> ids);
}
